import { Button, Form, Input, Select, DatePicker, Radio, message, Modal, Cascader, InputNumber } from "antd";
import { useState, useMemo, useEffect } from "react";
import { useStaff } from "@nice/client";
import { areaOptions } from './area-options';
import InfoCard from './infoCard';

const StaffInfoWrite = () => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  // 修改使用的hook方法
  const { create, setCustomFieldValue, useCustomFields } = useStaff();
  const { data: fields, isLoading: fieldsLoading } = useCustomFields();
  const [infoCards, setInfoCards] = useState<any[]>([]);
  
  // 添加跟踪培训和鉴定状态的state
  const [hasTrain, setHasTrain] = useState(false);
  const [hasCert, setHasCert] = useState(false);
  
  // 添加状态来跟踪每个文本区域的高度
  const [textAreaHeights, setTextAreaHeights] = useState<Record<string, number>>({});
  
  const handleAdd = (content: string) => {
    setInfoCards([...infoCards, { content }]);
  }
  
  // 在组件中添加监听字段变化
  useEffect(() => {
    // 设置默认值
    form.setFieldsValue({
      hasTrain: false,
      hasCert: false
    });
    
    // 使用 Form 的 onValuesChange 在外部监听
    const fieldChangeHandler = () => {
      const values = form.getFieldsValue(['hasTrain', 'hasCert']);
      setHasTrain(!!values.hasTrain);
      setHasCert(!!values.hasCert);
    };
    
    // 初始化时执行一次
    fieldChangeHandler();
    
    // 不需要返回取消订阅，因为我们不再使用 subscribe
  }, [form]);
  
  // 按分组组织字段
  const fieldGroups = useMemo(() => {
    if (!fields) return {};
    return fields.reduce((groups: any, field: any) => {
      const group = field.group || '其他信息';
      if (!groups[group]) {
        groups[group] = [];
      }
      groups[group].push(field);
      return groups;
    }, {});
  }, [fields]);

  // 检查字段是否应该被禁用的辅助函数
  const shouldFieldBeDisabled = (field: any, groupName: string) => {
    if (groupName === '培训信息' && !hasTrain) {
      return ['trainType', 'trainInstitute', 'trainMajor'].includes(field.name);
    }
    if (groupName === '鉴定信息' && !hasCert) {
      return ['certRank', 'certWork'].includes(field.name);
    }
    return false;
  };

  const renderField = (field: any, groupName: string) => {
    // 处理培训和鉴定的单选按钮
    if (field.name === 'hasTrain') {
      return (
        <Radio.Group 
          options={[
            { label: '是', value: true },
            { label: '否', value: false }
          ]}
          onChange={(e) => {
            setHasTrain(e.target.value);
            form.setFieldsValue({ hasTrain: e.target.value });
          }}
          value={hasTrain}
        />
      );
    }
    
    if (field.name === 'hasCert') {
      return (
        <Radio.Group 
          options={[
            { label: '是', value: true },
            { label: '否', value: false }
          ]}
          onChange={(e) => {
            setHasCert(e.target.value);
            form.setFieldsValue({ hasCert: e.target.value });
          }}
          value={hasCert}
        />
      );
    }
    
    // 检查字段是否应禁用
    const isDisabled = shouldFieldBeDisabled(field, groupName);
    
    // 如果是工作信息相关的字段，添加额外的类名
    const isWorkInfo = groupName === "工作信息";
    
    // 根据字段类型渲染不同的组件
    switch (field.type) {
      case 'text':
        return <Input disabled={isDisabled} />;
      case 'number':
        return <InputNumber disabled={isDisabled} />;
      case 'date':
        return <DatePicker disabled={isDisabled} />;
      case 'select':
        if (field.options && field.options.length > 0) {
          return <Select options={field.options} disabled={isDisabled} />;
        }
        return <Input placeholder="选项数据缺失" disabled={isDisabled} />;
      case 'radio':
        if (field.options && field.options.length > 0) {
          return <Radio.Group options={field.options} disabled={isDisabled} />;
        }
        return <Input placeholder="选项数据缺失" disabled={isDisabled} />;
      case 'textarea':
        return (
          <div 
            className="w-full relative" 
            style={{ 
              minHeight: textAreaHeights[field.name] ? 
                `${textAreaHeights[field.name]}px` : 'auto' 
            }}
          >
            <InfoCard 
              onAdd={handleAdd} 
              onHeightChange={(height) => {
                setTextAreaHeights(prev => ({
                  ...prev,
                  [field.name]: height
                }));
              }}
            />
          </div>
        );
      case 'cascader':
        if(field.label === '籍贯'){
          return <Cascader options={areaOptions} disabled={isDisabled} />;
        }else{
          return <Input disabled={isDisabled} />;
        }
      default:
        return <Input className="w-full" disabled={isDisabled} />;
    }
  };

  const onFinish = async (values: any) => {
    try {
      setLoading(true);
      
      // 创建基础员工记录
      const staff = await create.mutateAsync({
        data: {
          username: values.username,
          password: '123456'
        }
      });
  
      // 过滤有效字段并转换值
      const validEntries = Object.entries(values)
        .filter(([_, value]) => value !== undefined && value !== null && value !== '')
        .map(([fieldName, value]) => {
          const field = fields?.find((f: any) => f.name === fieldName);
          let processedValue = value;
          
          // 处理特殊字段类型
          if (field?.type === 'date' && value instanceof moment) {
            processedValue = value.format('YYYY-MM-DD');
          } else if (field?.type === 'cascader' && Array.isArray(value)) {
            processedValue = value.join('/');
          }
          
          return { field, value: processedValue };
        })
        .filter(item => item.field?.id); // 过滤有效字段定义
  
      // 批量提交自定义字段
      await Promise.all(
        validEntries.map(({ field, value }) =>
          setCustomFieldValue.mutateAsync({
            staffId: staff.id,
            fieldId: field.id,
            value: String(value)
          })
        )
      );
  
      message.success("信息提交成功");
    } catch (error) {
      console.error('提交出错:', error);
      message.error("提交失败，请重试");
    } finally {
      setLoading(false);
    }
  };

  if (fieldsLoading) {
    return <div>加载中...</div>;
  }

  return (
    <div className="max-w-4xl mx-auto p-6">
      <h1 className="text-2xl font-bold mb-6">人员信息管理</h1>

      <Form
        form={form}
        layout="vertical"
        onFinish={onFinish}
        onValuesChange={(changedValues) => {
          if ('hasTrain' in changedValues) {
            setHasTrain(!!changedValues.hasTrain);
          }
          if ('hasCert' in changedValues) {
            setHasCert(!!changedValues.hasCert);
          }
        }}
        className="space-y-6 mt-6"
      >
        {Object.entries(fieldGroups).map(([groupName, groupFields]) => (
          <div key={groupName} className="bg-white p-6 rounded-lg shadow relative">
            <h2 className="text-lg font-semibold mb-4">{groupName}</h2>
            <div className={`
              grid grid-cols-1 md:grid-cols-2 gap-x-6 gap-y-12
              ${groupName === "工作信息" ? "md:[&>*:nth-child(odd)]:col-start-1 md:[&>*:nth-child(even)]:col-start-2" : ""}
            `}>
              {groupFields.map((field: any) => (
                <Form.Item
                  key={field.id}
                  label={<span className="block mb-2">{field.label}</span>}
                  name={field.name}
                  rules={[
                    {
                      required: field.required,
                      message: `请输入${field.label}`,
                    },
                  ]}
                  className={`
                    ${field.type === 'textarea' && groupName !== "工作信息" ? "md:col-span-2" : ""}
                    ${field.type === 'textarea' ? "transition-all duration-200 ease-in-out" : ""} 
                  `}
                  style={{
                    minHeight: field.type === 'textarea' && textAreaHeights[field.name] ? 
                      `${textAreaHeights[field.name] + 50}px` : 'auto'
                  }}
                >
                  {renderField(field, groupName)}
                </Form.Item>
              ))}
            </div>
          </div>
        ))}

        <div className="flex justify-end space-x-4">
          <Button onClick={() => form.resetFields()}>重置</Button>
          <Button 
            type="primary" 
            htmlType="submit"
            loading={loading}
          >
            提交
          </Button>
        </div>
      </Form>
    </div>
  );
};

export default StaffInfoWrite;